@@ -1,7 +1,7 @@
 <?php
 /**
  * phpVirtualBox example configuration. 
- * @version $Id: config.php-example 452 2012-10-17 12:22:12Z imooreyahoo@gmail.com $
+ * @version $Id: config.php-example 585 2015-04-04 11:39:31Z imoore76 $
  *
  * rename to config.php and edit as needed.
  *
@@ -23,6 +23,8 @@ var $language = 'en';
 
 /* Set the standard VRDE Port Number / Range, e.g. 1010-1020 or 1027 */
 var $vrdeports = '9000-9100';
+/* Set the default VRDE address, e.g. 192.168.1.1 */
+#var $vrdeaddress = '192.168.1.1';
 
 /*
  *
@@ -181,7 +183,7 @@ var $nicMax = 4;
 #var $startStopConfig = true;
 
 // Authentication library.
-var $authLib = 'Builtin';
+// var $authLib = 'Builtin';
 
 // VM ownership
 #var $enforceVMOwnership = true;
@@ -211,6 +213,11 @@ LPT support may or may not work for you.
 */
 #var $enableHDFlushConfig = true;
 
+/*
+ * Event listener timeout in seconds. This is an advanced option that most people will
+ * probably not need to change.
+ */
+#var $eventListenerTimeout = 20;
 
 /* END SETTINGS  */
 
