@@ -248,19 +248,20 @@ function vboxGuestOSTypeIcon(osTypeId) {
 		case "Windows8":        strIcon = "os_win8.png"; break;
 		case "Windows8_64":     strIcon = "os_win8_64.png"; break;
 		case "Windows81":       strIcon = "os_win81.png"; break;
-		case "Windows81_64":     strIcon = "os_win81_64.png"; break;
+		case "Windows81_64":    strIcon = "os_win81_64.png"; break;
 		case "Windows10":       strIcon = "os_win10.png"; break
-		case "Windows10_64":       strIcon = "os_win10.png"; break
-		case "WindowsNT_64":
+		case "Windows10_64":    strIcon = "os_win10.png"; break
 		case "WindowsNT":       strIcon = "os_win_other.png"; break;
+		case "WindowsNT_64":    strIcon = "os_win_other_64.png"; break; 
 		case "Windows2012_64":	strIcon = "os_win2k12_64.png"; break;
+		case "Windows2016_64":	strIcon = "os_win2k16_64.png"; break;
 		case "OS2Warp3":        strIcon = "os_os2warp3.png"; break;
 		case "OS2Warp4":        strIcon = "os_os2warp4.png"; break;
 		case "OS2Warp45":       strIcon = "os_os2warp45.png"; break;
 		case "OS2eCS":          strIcon = "os_os2ecs.png"; break;
 		case "OS2":             strIcon = "os_os2_other.png"; break;
-		case "Linux_64":
-		case "Linux":           strIcon = "os_linux_other.png"; break;
+		case "Linux_64":        strIcon = "os_linux_64.png"; break;
+		case "Linux":           strIcon = "os_linux.png"; break;
 		case "Linux22":         strIcon = "os_linux22.png"; break;
 		case "Linux24":         strIcon = "os_linux24.png"; break;
 		case "Linux24_64":      strIcon = "os_linux24_64.png"; break;
@@ -281,7 +282,7 @@ function vboxGuestOSTypeIcon(osTypeId) {
 		case "RedHat":          strIcon = "os_redhat.png"; break;
 		case "RedHat_64":       strIcon = "os_redhat_64.png"; break;
 		case "Turbolinux":      strIcon = "os_turbolinux.png"; break;
-		case "Turbolinux_64":      strIcon = "os_turbolinux_64.png"; break;
+		case "Turbolinux_64":   strIcon = "os_turbolinux_64.png"; break;
 		case "Ubuntu":          strIcon = "os_ubuntu.png"; break;
 		case "Ubuntu_64":       strIcon = "os_ubuntu_64.png"; break;
 		case "Xandros":         strIcon = "os_xandros.png"; break;
@@ -294,18 +295,18 @@ function vboxGuestOSTypeIcon(osTypeId) {
 		case "NetBSD_64":       strIcon = "os_netbsd_64.png"; break;
 		case "Solaris":         strIcon = "os_solaris.png"; break;
 		case "Solaris_64":      strIcon = "os_solaris_64.png"; break;
-		case "Solaris11_64":      strIcon = "os_oraclesolaris_64.png"; break;
+		case "Solaris11_64":    strIcon = "os_oraclesolaris_64.png"; break;
 		case "OpenSolaris":     strIcon = "os_oraclesolaris.png"; break;
 		case "OpenSolaris_64":  strIcon = "os_oraclesolaris_64.png"; break;
 		case "QNX":             strIcon = "os_qnx.png"; break;
-		case "MacOS106":
-		case 'MacOS':			strIcon = "os_macosx.png"; break;
-		case "MacOS106_64":
-		case 'MacOS_64':			strIcon = "os_macosx_64.png"; break;
-		case 'Oracle':			strIcon = "os_oracle.png"; break;
-		case 'Oracle_64':			strIcon = "os_oracle_64.png"; break;
-		case 'JRockitVE':		strIcon = 'os_jrockitve.png'; break;
-		case "VirtualBox_Host":	strIcon = "os_virtualbox.png"; break;
+		case "MacOS106":        strIcon = "os_macosx.png"; break;
+		case 'MacOS':           strIcon = "os_macosx.png"; break;
+		case "MacOS106_64":     strIcon = "os_macosx_64.png"; break;
+		case 'MacOS_64':        strIcon = "os_macosx_64.png"; break;
+		case 'Oracle':          strIcon = "os_oracle.png"; break;
+		case 'Oracle_64':       strIcon = "os_oracle_64.png"; break;
+		case 'JRockitVE':       strIcon = 'os_jrockitve.png'; break;
+		case "VirtualBox_Host": strIcon = "os_virtualbox.png"; break;
 
         default:
             break;
